summaryrefslogtreecommitdiff
path: root/src/library/scala/BigDecimal.scala
diff options
context:
space:
mode:
authorPaul Phillips <paulp@improving.org>2009-11-06 19:25:10 +0000
committerPaul Phillips <paulp@improving.org>2009-11-06 19:25:10 +0000
commitf540f0350315c2af8779286f85084405cdbf0d76 (patch)
tree3b778ca201f97c6c105205fcf01dceb9429793f8 /src/library/scala/BigDecimal.scala
parent5d25e9334d6dfd492cb5312a43b3d3f36042401a (diff)
downloadscala-f540f0350315c2af8779286f85084405cdbf0d76.tar.gz
scala-f540f0350315c2af8779286f85084405cdbf0d76.tar.bz2
scala-f540f0350315c2af8779286f85084405cdbf0d76.zip
- Renames filterMap to partialMap
- Renames GenericRange to NumericRange - Removes most @experimental annotations
Diffstat (limited to 'src/library/scala/BigDecimal.scala')
-rw-r--r--src/library/scala/BigDecimal.scala12
1 files changed, 6 insertions, 6 deletions
diff --git a/src/library/scala/BigDecimal.scala b/src/library/scala/BigDecimal.scala
index fc874db1f2..b43e4b2a04 100644
--- a/src/library/scala/BigDecimal.scala
+++ b/src/library/scala/BigDecimal.scala
@@ -12,7 +12,7 @@ package scala
import java.{ lang => jl }
import java.math.{ MathContext, BigDecimal => BigDec }
-import scala.collection.immutable.GenericRange
+import scala.collection.immutable.NumericRange
/** Conversions which present a consistent conversion interface
* across all the numeric types.
@@ -359,27 +359,27 @@ extends jl.Number with ScalaNumericConversions
def toIntExact = bigDecimal.intValueExact
def toLongExact = bigDecimal.longValueExact
/** Creates a partially constructed GenericRange[BigDecimal] in range
* <code>[start;end)</code>, where start is the target BigDecimal. The step
* must be supplied via the "by" method of the returned object in order
* to receive the fully constructed range. For example:
* <pre>
* val partial = BigDecimal(1.0) to 2.0 // not usable yet
* val range = partial by 0.01 // now a GenericRange
* val range2 = BigDecimal(0) to 1.0 by 0.01 // all at once of course is fine too
* </pre>
*
* @param end the end value of the range (exclusive)
* @return the partially constructed GenericRange
*/
- def until(end: BigDecimal): Range.Partial[BigDecimal, GenericRange.Exclusive[BigDecimal]] =
+ def until(end: BigDecimal): Range.Partial[BigDecimal, NumericRange.Exclusive[BigDecimal]] =
new Range.Partial(until(end, _))
/** Same as the one-argument <code>until</code>, but creates the range immediately. */
def until(end: BigDecimal, step: BigDecimal) = Range.BigDecimal(this, end, step)
/** Like <code>until</code>, but inclusive of the end value. */
- def to(end: BigDecimal): Range.Partial[BigDecimal, GenericRange.Inclusive[BigDecimal]] =
+ def to(end: BigDecimal): Range.Partial[BigDecimal, NumericRange.Inclusive[BigDecimal]] =
new Range.Partial(to(end, _))
/** Like <code>until</code>, but inclusive of the end value. */
@@ -359,27 +359,27 @@ extends jl.Number with ScalaNumericConversions
def toIntExact = bigDecimal.intValueExact
def toLongExact = bigDecimal.longValueExact
- /** Creates a partially constructed GenericRange[BigDecimal] in range
+ /** Creates a partially constructed NumericRange[BigDecimal] in range
* <code>[start;end)</code>, where start is the target BigDecimal. The step
* must be supplied via the "by" method of the returned object in order
@@ -359,27 +359,27 @@ extends jl.Number with ScalaNumericConversions
* <pre>
* val partial = BigDecimal(1.0) to 2.0 // not usable yet
- * val range = partial by 0.01 // now a GenericRange
+ * val range = partial by 0.01 // now a NumericRange
* val range2 = BigDecimal(0) to 1.0 by 0.01 // all at once of course is fine too
* </pre>
@@ -359,27 +359,27 @@ extends jl.Number with ScalaNumericConversions
*
* @param end the end value of the range (exclusive)
- * @return the partially constructed GenericRange
+ * @return the partially constructed NumericRange
*/